#
# Copyright 2001 Stfane Fermigier and Nuxeo SARL
# See LICENSE.TXT for licensing information
#

"""NuxDocuments

"""

__version__='$Revision: 1.14 $'[11:-2]

from OFS.SimpleItem import SimpleItem, Item_w__name__
from OFS.ObjectManager import ObjectManager
from OFS.Cache import Cacheable
from OFS.History import Historical
from OFS.Image import File
import Acquisition
from DateTime.DateTime import DateTime

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass

from urllib import quote
import re, string, traceback

import plugins


class NuxDocument(SimpleItem, ObjectManager):
  # (SimpleItem):
  # (CatalogAware, SimpleItem, Acquisition.Implicit, 
  # PropertyManager, Historical, Cacheable, Item_w__name__):
  # + ElementWithTitle (XXX ???)

  index_html = None # Prevent accidental acquisition (XXX ???)

  _text = _html = ''
  _file = None

  security = ClassSecurityInfo()

  #
  # Constructor
  #
  def __init__(self, id='', title='', file='', mime_type=''):
    self._setId(id)
    self._edit(title, file, mime_type)

  def _edit(self, title=None, file=None, mime_type=None):
    if title is not None:
      self.title = title
    if file is not None:
      self._file = File(self.__name__, title, file)
    if mime_type is not None:
      self.mime_type = mime_type
    else:
      self.mime_type = self._file.content_type
    if file is not None:
      self.convert()
    self.filename = getattr(self._file, 'filename', self.__name__)
    self.publication_date = DateTime()

  def convert(self):
    file = self.getRaw()
    plugin = plugins.selectPlugin(file, self.mime_type)

    if plugin != plugins.Dumb:
      try:
        result = plugin.getConverter(self.id, file)
      except:
        traceback.print_exc()
        plugin = plugins.getDefaultPlugin()
        result = plugin.getConverter(self.id, file)
    else:
      result = plugin.getConverter(self.id, file)

    self.mime_type = result.getMimeType() or self.mime_type
    self._text = result.getText()
    self._html = result.getHtml()
    for image_name in result.getImageNames():
      self.manage_addImage(image_name, result.getImage(image_name))

  #
  # Accessors / rendering
  #
  security.declareProtected('View', 'getHtml')
  def getHtml(self):
    return self._html

  security.declarePrivate('getRaw')
  def getRaw(self):
    return str(self._file)
  
  security.declareProtected('View', 'MimeType')
  def MimeType(self):
    """This document's mime-type"""
    return self.mime_type

  security.declareProtected('View', 'document_src')
  def document_src(self, REQUEST=None, RESPONSE=None):
    """Unprocessed document source."""

    if RESPONSE is not None:
      RESPONSE.setHeader('Content-Type', self.mime_type)
    return self.getRaw()

  security.declareProtected('FTP access', 'manage_FTPget')
  def manage_FTPget(self):
    "Get source for FTP download"

    return self.getRaw()

  security.declareProtected('View', 'PrincipiaSearchSource')
  def PrincipiaSearchSource(self):
    return self._text
    #return string.join(re.split(r'[^%s]+' % string.letters, self._text))

  security.declareProtected('View', 'SearchableText')
  def SearchableText(self):
    return "%s %s %s" % (
      self.title, self.Description(), self.PrincipiaSearchSource())

  security.declareProtected('Edit NuxDocument', 'PUT')
  def PUT(self, REQUEST, RESPONSE):
    "Handle HTTP/FTP PUT requests."

    self.dav__init(REQUEST, RESPONSE)
    self.html_src = REQUEST.get('BODY', '')
    self.updateState()
    self.ZCacheable_invalidate()
    self.reindex_object()
    RESPONSE.setStatus(204)
    return RESPONSE

InitializeClass(NuxDocument)

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
# 
# vim:et:ts=2:ai
